# DilllonB07 Utilities

Dill_tils is a package that has my commonly used functions inside it for ease of use.

## Installation

Anyone can use this package by installing it from PyPi via one of the following commands:

### Pip

```zsh
pip install dill_tils
```

```zsh
pip3 install dill_tils
```

```zsh
python -m pip install dill_tils
```

```zsh
python3 -m pip install dill_tils
```

### Poetry

```zsh
poetry install dill_tils
```

### Conda

```zsh
conda install dill_tils
```

### Pipenv

```zsh
pipenv install dill_tils
```

## Usage

Just import the modules you need and get started!

## License

This project is licensed under the LGPLv3 license.
